/*
 * Copyright (c) 1994 Cygnus Support.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that the above copyright notice and this paragraph are
 * duplicated in all such forms and that any documentation,
 * and/or other materials related to such
 * distribution and use acknowledge that the software was developed
 * at Cygnus Support, Inc.  Cygnus Support, Inc. may not be used to
 * endorse or promote products derived from this software without
 * specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */
#include "test.h"
 one_line_type erfc_vec[] = {
{64, 0,123,__LINE__, 0x3ffe90a5, 0x63d96834, 0xbff33333, 0x33333333},	/* 1.91031=f(-1.2)*/
{64, 0,123,__LINE__, 0x3ffe8590, 0x441d3b67, 0xbff30a3d, 0x70a3d70a},	/* 1.90761=f(-1.19)*/
{64, 0,123,__LINE__, 0x3ffe7a36, 0xcf4cc329, 0xbff2e147, 0xae147ae1},	/* 1.90484=f(-1.18)*/
{64, 0,123,__LINE__, 0x3ffe6e97, 0xf8689a32, 0xbff2b851, 0xeb851eb8},	/* 1.902=f(-1.17)*/
{64, 0,123,__LINE__, 0x3ffe62b2, 0xb33537e3, 0xbff28f5c, 0x28f5c28f},	/* 1.8991=f(-1.16)*/
{64, 0,123,__LINE__, 0x3ffe5685, 0xf469473b, 0xbff26666, 0x66666666},	/* 1.89612=f(-1.15)*/
{64, 0,123,__LINE__, 0x3ffe4a10, 0xb1dce486, 0xbff23d70, 0xa3d70a3d},	/* 1.89308=f(-1.14)*/
{64, 0,123,__LINE__, 0x3ffe3d51, 0xe2b9badb, 0xbff2147a, 0xe147ae14},	/* 1.88997=f(-1.13)*/
{64, 0,123,__LINE__, 0x3ffe3048, 0x7fabfa4d, 0xbff1eb85, 0x1eb851eb},	/* 1.88679=f(-1.12)*/
{64, 0,123,__LINE__, 0x3ffe22f3, 0x83141f08, 0xbff1c28f, 0x5c28f5c2},	/* 1.88353=f(-1.11)*/
{64, 0,123,__LINE__, 0x3ffe1551, 0xe9398160, 0xbff19999, 0x99999999},	/* 1.88021=f(-1.1)*/
{64, 0,123,__LINE__, 0x3ffe0762, 0xb07da638, 0xbff170a3, 0xd70a3d70},	/* 1.8768=f(-1.09)*/
{64, 0,123,__LINE__, 0x3ffdf924, 0xd99046de, 0xbff147ae, 0x147ae147},	/* 1.87333=f(-1.08)*/
{64, 0,123,__LINE__, 0x3ffdea97, 0x67a406f0, 0xbff11eb8, 0x51eb851e},	/* 1.86977=f(-1.07)*/
{64, 0,123,__LINE__, 0x3ffddbb9, 0x60a3ce91, 0xbff0f5c2, 0x8f5c28f5},	/* 1.86614=f(-1.06)*/
{64, 0,123,__LINE__, 0x3ffdcc89, 0xcd68bead, 0xbff0cccc, 0xcccccccc},	/* 1.86244=f(-1.05)*/
{64, 0,123,__LINE__, 0x3ffdbd07, 0xb9f0b4b3, 0xbff0a3d7, 0x0a3d70a3},	/* 1.85865=f(-1.04)*/
{64, 0,123,__LINE__, 0x3ffdad32, 0x359552ce, 0xbff07ae1, 0x47ae147a},	/* 1.85478=f(-1.03)*/
{64, 0,123,__LINE__, 0x3ffd9d08, 0x53438116, 0xbff051eb, 0x851eb851},	/* 1.85084=f(-1.02)*/
{63, 0,123,__LINE__, 0x3ffd8c89, 0x29b35c13, 0xbff028f5, 0xc28f5c28},	/* 1.84681=f(-1.01)*/
{64, 0,123,__LINE__, 0x3ffd7bb3, 0xd3a08445, 0xbfefffff, 0xfffffffe},	/* 1.8427=f(-1)*/
{63, 0,123,__LINE__, 0x3ffd6a87, 0x7002c22d, 0xbfefae14, 0x7ae147ac},	/* 1.83851=f(-0.99)*/
{64, 0,123,__LINE__, 0x3ffd5903, 0x2246f1f8, 0xbfef5c28, 0xf5c28f5a},	/* 1.83423=f(-0.98)*/
{64, 0,123,__LINE__, 0x3ffd4726, 0x1288297a, 0xbfef0a3d, 0x70a3d708},	/* 1.82987=f(-0.97)*/
{64, 0,123,__LINE__, 0x3ffd34ef, 0x6dc90ae6, 0xbfeeb851, 0xeb851eb6},	/* 1.82542=f(-0.96)*/
{63, 0,123,__LINE__, 0x3ffd225e, 0x662d3658, 0xbfee6666, 0x66666664},	/* 1.82089=f(-0.95)*/
{64, 0,123,__LINE__, 0x3ffcfc2a, 0x11ebefd7, 0xbfedc28f, 0x5c28f5c0},	/* 1.81156=f(-0.93)*/
{64, 0,123,__LINE__, 0x3ffce885, 0x453841d3, 0xbfed70a3, 0xd70a3d6e},	/* 1.80677=f(-0.92)*/
{63, 0,123,__LINE__, 0x3ffcd483, 0x15fe3875, 0xbfed1eb8, 0x51eb851c},	/* 1.80188=f(-0.91)*/
{64, 0,123,__LINE__, 0x3ffcc022, 0xd3645172, 0xbfeccccc, 0xccccccca},	/* 1.79691=f(-0.9)*/
{64, 0,123,__LINE__, 0x3ffcab63, 0xd30a0704, 0xbfec7ae1, 0x47ae1478},	/* 1.79184=f(-0.89)*/
{64, 0,123,__LINE__, 0x3ffc9645, 0x71407ab0, 0xbfec28f5, 0xc28f5c26},	/* 1.78669=f(-0.88)*/
{64, 0,123,__LINE__, 0x3ffc80c7, 0x1142c575, 0xbfebd70a, 0x3d70a3d4},	/* 1.78144=f(-0.87)*/
{64, 0,123,__LINE__, 0x3ffc6ae8, 0x1d6ddd2f, 0xbfeb851e, 0xb851eb82},	/* 1.7761=f(-0.86)*/
{64, 0,123,__LINE__, 0x3ffc54a8, 0x0777fed8, 0xbfeb3333, 0x33333330},	/* 1.77067=f(-0.85)*/
{63, 0,123,__LINE__, 0x3ffc3e06, 0x48a78d2b, 0xbfeae147, 0xae147ade},	/* 1.76514=f(-0.84)*/
{64, 0,123,__LINE__, 0x3ffc2702, 0x62095319, 0xbfea8f5c, 0x28f5c28c},	/* 1.75952=f(-0.83)*/
{64, 0,123,__LINE__, 0x3ffc0f9b, 0xdca61942, 0xbfea3d70, 0xa3d70a3a},	/* 1.75381=f(-0.82)*/
{64, 0,123,__LINE__, 0x3ffbf7d2, 0x49b77dd1, 0xbfe9eb85, 0x1eb851e8},	/* 1.748=f(-0.81)*/
{64, 0,123,__LINE__, 0x3ffbdfa5, 0x42dbfdc0, 0xbfe99999, 0x99999996},	/* 1.7421=f(-0.8)*/
{64, 0,123,__LINE__, 0x3ffbc714, 0x6a4a1ec6, 0xbfe947ae, 0x147ae144},	/* 1.7361=f(-0.79)*/
{64, 0,123,__LINE__, 0x3ffbae1f, 0x6b02a8f6, 0xbfe8f5c2, 0x8f5c28f2},	/* 1.73001=f(-0.78)*/
{64, 0,123,__LINE__, 0x3ffb94c5, 0xf901df42, 0xbfe8a3d7, 0x0a3d70a0},	/* 1.72382=f(-0.77)*/
{63, 0,123,__LINE__, 0x3ffb7b07, 0xd16fa615, 0xbfe851eb, 0x851eb84e},	/* 1.71754=f(-0.76)*/
{64, 0,123,__LINE__, 0x3ffb60e4, 0xbace872e, 0xbfe7ffff, 0xfffffffc},	/* 1.71116=f(-0.75)*/
{64, 0,123,__LINE__, 0x3ffb465c, 0x85298225, 0xbfe7ae14, 0x7ae147aa},	/* 1.70468=f(-0.74)*/
{64, 0,123,__LINE__, 0x3ffb2b6f, 0x0a409902, 0xbfe75c28, 0xf5c28f58},	/* 1.6981=f(-0.73)*/
{64, 0,123,__LINE__, 0x3ffb101c, 0x2db40880, 0xbfe70a3d, 0x70a3d706},	/* 1.69143=f(-0.72)*/
{64, 0,123,__LINE__, 0x3ffaf463, 0xdd2e1bb8, 0xbfe6b851, 0xeb851eb4},	/* 1.68467=f(-0.71)*/
{64, 0,123,__LINE__, 0x3ffad846, 0x108b8b22, 0xbfe66666, 0x66666662},	/* 1.6778=f(-0.7)*/
{64, 0,123,__LINE__, 0x3ffabbc2, 0xca025717, 0xbfe6147a, 0xe147ae10},	/* 1.67084=f(-0.69)*/
{64, 0,123,__LINE__, 0x3ffa9eda, 0x16470e39, 0xbfe5c28f, 0x5c28f5be},	/* 1.66378=f(-0.68)*/
{64, 0,123,__LINE__, 0x3ffa818c, 0x0cb0705d, 0xbfe570a3, 0xd70a3d6c},	/* 1.65663=f(-0.67)*/
{64, 0,123,__LINE__, 0x3ffa63d8, 0xcf595ef6, 0xbfe51eb8, 0x51eb851a},	/* 1.64938=f(-0.66)*/
{64, 0,123,__LINE__, 0x3ffa45c0, 0x8b410c3c, 0xbfe4cccc, 0xccccccc8},	/* 1.64203=f(-0.65)*/
{64, 0,123,__LINE__, 0x3ffa2743, 0x78695aaf, 0xbfe47ae1, 0x47ae1476},	/* 1.63459=f(-0.64)*/
{64, 0,123,__LINE__, 0x3ffa0861, 0xd9f35ee3, 0xbfe428f5, 0xc28f5c24},	/* 1.62705=f(-0.63)*/
{64, 0,123,__LINE__, 0x3ff9e91b, 0xfe39f5fd, 0xbfe3d70a, 0x3d70a3d2},	/* 1.61941=f(-0.62)*/
{64, 0,123,__LINE__, 0x3ff9c972, 0x3eea639f, 0xbfe3851e, 0xb851eb80},	/* 1.61168=f(-0.61)*/
{64, 0,123,__LINE__, 0x3ff9a965, 0x011aea7a, 0xbfe33333, 0x3333332e},	/* 1.60386=f(-0.6)*/
{64, 0,123,__LINE__, 0x3ff988f4, 0xb55f5332, 0xbfe2e147, 0xae147adc},	/* 1.59594=f(-0.59)*/
{64, 0,123,__LINE__, 0x3ff96821, 0xd7db55c4, 0xbfe28f5c, 0x28f5c28a},	/* 1.58792=f(-0.58)*/
{63, 0,123,__LINE__, 0x3ff946ec, 0xf052da0e, 0xbfe23d70, 0xa3d70a38},	/* 1.57982=f(-0.57)*/
{64, 0,123,__LINE__, 0x3ff92556, 0x923804af, 0xbfe1eb85, 0x1eb851e6},	/* 1.57162=f(-0.56)*/
{63, 0,123,__LINE__, 0x3ff9035f, 0x5cb70604, 0xbfe19999, 0x99999994},	/* 1.56332=f(-0.55)*/
{64, 0,123,__LINE__, 0x3ff8e107, 0xfabfa193, 0xbfe147ae, 0x147ae142},	/* 1.55494=f(-0.54)*/
{64, 0,123,__LINE__, 0x3ff8be51, 0x230c64c8, 0xbfe0f5c2, 0x8f5c28f0},	/* 1.54646=f(-0.53)*/
{64, 0,123,__LINE__, 0x3ff89b3b, 0x98278492, 0xbfe0a3d7, 0x0a3d709e},	/* 1.5379=f(-0.52)*/
{64, 0,123,__LINE__, 0x3ff877c8, 0x286d5a09, 0xbfe051eb, 0x851eb84c},	/* 1.52924=f(-0.51)*/
{64, 0,123,__LINE__, 0x3ff853f7, 0xae0c76e6, 0xbfdfffff, 0xfffffff4},	/* 1.5205=f(-0.5)*/
{63, 0,123,__LINE__, 0x3ff82fcb, 0x0f034b54, 0xbfdf5c28, 0xf5c28f50},	/* 1.51167=f(-0.49)*/
{64, 0,123,__LINE__, 0x3ff80b43, 0x3d1b572c, 0xbfdeb851, 0xeb851eac},	/* 1.50275=f(-0.48)*/
{63, 0,123,__LINE__, 0x3ff7e661, 0x35e1e197, 0xbfde147a, 0xe147ae08},	/* 1.49375=f(-0.47)*/
{64, 0,123,__LINE__, 0x3ff7c126, 0x029e3288, 0xbfdd70a3, 0xd70a3d64},	/* 1.48466=f(-0.46)*/
{64, 0,123,__LINE__, 0x3ff79b92, 0xb8454a6d, 0xbfdccccc, 0xccccccc0},	/* 1.47548=f(-0.45)*/
{64, 0,123,__LINE__, 0x3ff775a8, 0x776b151d, 0xbfdc28f5, 0xc28f5c1c},	/* 1.46623=f(-0.44)*/
{64, 0,123,__LINE__, 0x3ff74f68, 0x6c3115c4, 0xbfdb851e, 0xb851eb78},	/* 1.45689=f(-0.43)*/
{64, 0,123,__LINE__, 0x3ff728d3, 0xce328a60, 0xbfdae147, 0xae147ad4},	/* 1.44747=f(-0.42)*/
{64, 0,123,__LINE__, 0x3ff701eb, 0xe06e0615, 0xbfda3d70, 0xa3d70a30},	/* 1.43797=f(-0.41)*/
{64, 0,123,__LINE__, 0x3ff6dab1, 0xf12c827e, 0xbfd99999, 0x9999998c},	/* 1.42839=f(-0.4)*/
{64, 0,123,__LINE__, 0x3ff6b327, 0x59e5e8c0, 0xbfd8f5c2, 0x8f5c28e8},	/* 1.41874=f(-0.39)*/
{64, 0,123,__LINE__, 0x3ff68b4d, 0x7f231425, 0xbfd851eb, 0x851eb844},	/* 1.40901=f(-0.38)*/
{64, 0,123,__LINE__, 0x3ff66325, 0xd05d5098, 0xbfd7ae14, 0x7ae147a0},	/* 1.39921=f(-0.37)*/
{64, 0,123,__LINE__, 0x3ff63ab1, 0xc7db5853, 0xbfd70a3d, 0x70a3d6fc},	/* 1.38933=f(-0.36)*/
{64, 0,123,__LINE__, 0x3ff611f2, 0xea8bd4bf, 0xbfd66666, 0x66666658},	/* 1.37938=f(-0.35)*/
{63, 0,123,__LINE__, 0x3ff5e8ea, 0xc7dd6760, 0xbfd5c28f, 0x5c28f5b4},	/* 1.36936=f(-0.34)*/
{64, 0,123,__LINE__, 0x3ff5bf9a, 0xf9944074, 0xbfd51eb8, 0x51eb8510},	/* 1.35928=f(-0.33)*/
{64, 0,123,__LINE__, 0x3ff59605, 0x239d49b0, 0xbfd47ae1, 0x47ae146c},	/* 1.34913=f(-0.32)*/
{64, 0,123,__LINE__, 0x3ff56c2a, 0xf3deec4f, 0xbfd3d70a, 0x3d70a3c8},	/* 1.33891=f(-0.31)*/
{64, 0,123,__LINE__, 0x3ff5420e, 0x22077a80, 0xbfd33333, 0x33333324},	/* 1.32863=f(-0.3)*/
{64, 0,123,__LINE__, 0x3ff517b0, 0x6f5944f7, 0xbfd28f5c, 0x28f5c280},	/* 1.31828=f(-0.29)*/
{64, 0,123,__LINE__, 0x3ff4ed13, 0xa6746634, 0xbfd1eb85, 0x1eb851dc},	/* 1.30788=f(-0.28)*/
{64, 0,123,__LINE__, 0x3ff4c239, 0x9b1e4dcf, 0xbfd147ae, 0x147ae138},	/* 1.29742=f(-0.27)*/
{64, 0,123,__LINE__, 0x3ff49724, 0x2a0716e6, 0xbfd0a3d7, 0x0a3d7094},	/* 1.2869=f(-0.26)*/
{64, 0,123,__LINE__, 0x3ff46bd5, 0x388cb57e, 0xbfcfffff, 0xffffffe0},	/* 1.27633=f(-0.25)*/
{64, 0,123,__LINE__, 0x3ff4404e, 0xb47c0764, 0xbfceb851, 0xeb851e98},	/* 1.2657=f(-0.24)*/
{64, 0,123,__LINE__, 0x3ff41492, 0x93cfd5dc, 0xbfcd70a3, 0xd70a3d50},	/* 1.25502=f(-0.23)*/
{64, 0,123,__LINE__, 0x3ff3e8a2, 0xd46dd60f, 0xbfcc28f5, 0xc28f5c08},	/* 1.2443=f(-0.22)*/
{64, 0,123,__LINE__, 0x3ff3bc81, 0x7be1b6ef, 0xbfcae147, 0xae147ac0},	/* 1.23352=f(-0.21)*/
{64, 0,123,__LINE__, 0x3ff39030, 0x97164bdf, 0xbfc99999, 0x99999978},	/* 1.2227=f(-0.2)*/
{64, 0,123,__LINE__, 0x3ff363b2, 0x3a0ce423, 0xbfc851eb, 0x851eb830},	/* 1.21184=f(-0.19)*/
{64, 0,123,__LINE__, 0x3ff33708, 0x7f92dfb4, 0xbfc70a3d, 0x70a3d6e8},	/* 1.20094=f(-0.18)*/
{64, 0,123,__LINE__, 0x3ff30a35, 0x88f592b1, 0xbfc5c28f, 0x5c28f5a0},	/* 1.18999=f(-0.17)*/
{64, 0,123,__LINE__, 0x3ff2dd3b, 0x7db4894d, 0xbfc47ae1, 0x47ae1458},	/* 1.17901=f(-0.16)*/
{64, 0,123,__LINE__, 0x3ff2b01c, 0x8b323e8e, 0xbfc33333, 0x33333310},	/* 1.168=f(-0.15)*/
{64, 0,123,__LINE__, 0x3ff282da, 0xe46358d9, 0xbfc1eb85, 0x1eb851c8},	/* 1.15695=f(-0.14)*/
{64, 0,123,__LINE__, 0x3ff25578, 0xc17c7fbc, 0xbfc0a3d7, 0x0a3d7080},	/* 1.14587=f(-0.13)*/
{64, 0,123,__LINE__, 0x3ff227f8, 0x5f9edee1, 0xbfbeb851, 0xeb851e71},	/* 1.13476=f(-0.12)*/
{64, 0,123,__LINE__, 0x3ff1fa5c, 0x00836aa9, 0xbfbc28f5, 0xc28f5be2},	/* 1.12362=f(-0.11)*/
{64, 0,123,__LINE__, 0x3ff1cca5, 0xea24fb2e, 0xbfb99999, 0x99999953},	/* 1.11246=f(-0.1)*/
{64, 0,123,__LINE__, 0x3ff19ed8, 0x6669530b, 0xbfb70a3d, 0x70a3d6c4},	/* 1.10128=f(-0.09)*/
{64, 0,123,__LINE__, 0x3ff170f5, 0xc2c9277d, 0xbfb47ae1, 0x47ae1435},	/* 1.09008=f(-0.08)*/
{64, 0,123,__LINE__, 0x3ff14300, 0x4ff73fea, 0xbfb1eb85, 0x1eb851a6},	/* 1.07886=f(-0.07)*/
{64, 0,123,__LINE__, 0x3ff114fa, 0x6186c31a, 0xbfaeb851, 0xeb851e2d},	/* 1.06762=f(-0.06)*/
{64, 0,123,__LINE__, 0x3ff0e6e6, 0x4d90c8c9, 0xbfa99999, 0x9999990e},	/* 1.05637=f(-0.05)*/
{64, 0,123,__LINE__, 0x3ff0b8c6, 0x6c59466a, 0xbfa47ae1, 0x47ae13ef},	/* 1.04511=f(-0.04)*/
{64, 0,123,__LINE__, 0x3ff08a9d, 0x17f36e3d, 0xbf9eb851, 0xeb851da0},	/* 1.03384=f(-0.03)*/
{64, 0,123,__LINE__, 0x3ff05c6c, 0xabe5980a, 0xbf947ae1, 0x47ae1362},	/* 1.02256=f(-0.02)*/
{64, 0,123,__LINE__, 0x3ff02e37, 0x84cccaf2, 0xbf847ae1, 0x47ae1249},	/* 1.01128=f(-0.01)*/
{64, 0,123,__LINE__, 0x3fefffff, 0xfffffff6, 0x3cd19000, 0x00000000},	/* 1=f(9.74915e-16)*/
{64, 0,123,__LINE__, 0x3fefa390, 0xf6666a09, 0x3f847ae1, 0x47ae16ad},	/* 0.988717=f(0.01)*/
{64, 0,123,__LINE__, 0x3fef4726, 0xa834cfd9, 0x3f947ae1, 0x47ae1594},	/* 0.977435=f(0.02)*/
{64, 0,123,__LINE__, 0x3feeeac5, 0xd0192372, 0x3f9eb851, 0xeb851fd2},	/* 0.966159=f(0.03)*/
{64, 0,123,__LINE__, 0x3fee8e73, 0x274d7319, 0x3fa47ae1, 0x47ae1508},	/* 0.954889=f(0.04)*/
{64, 0,123,__LINE__, 0x3fee3233, 0x64de6e5a, 0x3fa99999, 0x99999a27},	/* 0.943628=f(0.05)*/
{64, 0,123,__LINE__, 0x3fedd60b, 0x3cf279b9, 0x3faeb851, 0xeb851f46},	/* 0.932378=f(0.06)*/
{64, 0,123,__LINE__, 0x3fed79ff, 0x60118019, 0x3fb1eb85, 0x1eb85232},	/* 0.921142=f(0.07)*/
{64, 0,123,__LINE__, 0x3fed1e14, 0x7a6db0f2, 0x3fb47ae1, 0x47ae14c1},	/* 0.909922=f(0.08)*/
{64, 0,123,__LINE__, 0x3fecc24f, 0x332d59d6, 0x3fb70a3d, 0x70a3d750},	/* 0.898719=f(0.09)*/
{64, 0,123,__LINE__, 0x3fec66b4, 0x2bb60990, 0x3fb99999, 0x999999df},	/* 0.887537=f(0.1)*/
{64, 0,123,__LINE__, 0x3fec0b47, 0xfef92a9a, 0x3fbc28f5, 0xc28f5c6e},	/* 0.876377=f(0.11)*/
{64, 0,123,__LINE__, 0x3febb00f, 0x40c2422a, 0x3fbeb851, 0xeb851efd},	/* 0.865242=f(0.12)*/
{64, 0,123,__LINE__, 0x3feb550e, 0x7d070075, 0x3fc0a3d7, 0x0a3d70c6},	/* 0.854133=f(0.13)*/
{64, 0,123,__LINE__, 0x3feafa4a, 0x37394e3a, 0x3fc1eb85, 0x1eb8520e},	/* 0.843053=f(0.14)*/
{64, 0,123,__LINE__, 0x3fea9fc6, 0xe99b82d1, 0x3fc33333, 0x33333356},	/* 0.832004=f(0.15)*/
{63, 0,123,__LINE__, 0x3fea4589, 0x0496ed53, 0x3fc47ae1, 0x47ae149e},	/* 0.820988=f(0.16)*/
{63, 0,123,__LINE__, 0x3fe9eb94, 0xee14da8b, 0x3fc5c28f, 0x5c28f5e6},	/* 0.810008=f(0.17)*/
{64, 0,123,__LINE__, 0x3fe991ef, 0x00da4086, 0x3fc70a3d, 0x70a3d72e},	/* 0.799064=f(0.18)*/
{64, 0,123,__LINE__, 0x3fe9389b, 0x8be637a7, 0x3fc851eb, 0x851eb876},	/* 0.78816=f(0.19)*/
{63, 0,123,__LINE__, 0x3fe8df9e, 0xd1d3682f, 0x3fc99999, 0x999999be},	/* 0.777297=f(0.2)*/
{63, 0,123,__LINE__, 0x3fe886fd, 0x083c920f, 0x3fcae147, 0xae147b06},	/* 0.766478=f(0.21)*/
{63, 0,123,__LINE__, 0x3fe82eba, 0x572453cf, 0x3fcc28f5, 0xc28f5c4e},	/* 0.755704=f(0.22)*/
{63, 0,123,__LINE__, 0x3fe7d6da, 0xd8605435, 0x3fcd70a3, 0xd70a3d96},	/* 0.744977=f(0.23)*/
{64, 0,123,__LINE__, 0x3fe77f62, 0x9707f125, 0x3fceb851, 0xeb851ede},	/* 0.7343=f(0.24)*/
{64, 0,123,__LINE__, 0x3fe72855, 0x8ee694f2, 0x3fd00000, 0x00000013},	/* 0.723674=f(0.25)*/
{64, 0,123,__LINE__, 0x3fe6d1b7, 0xabf1d221, 0x3fd0a3d7, 0x0a3d70b7},	/* 0.7131=f(0.26)*/
{63, 0,123,__LINE__, 0x3fe67b8c, 0xc9c3644f, 0x3fd147ae, 0x147ae15b},	/* 0.702582=f(0.27)*/
{64, 0,123,__LINE__, 0x3fe625d8, 0xb3173385, 0x3fd1eb85, 0x1eb851ff},	/* 0.69212=f(0.28)*/
{63, 0,123,__LINE__, 0x3fe5d09f, 0x214d75ff, 0x3fd28f5c, 0x28f5c2a3},	/* 0.681717=f(0.29)*/
{64, 0,123,__LINE__, 0x3fe57be3, 0xbbf10aee, 0x3fd33333, 0x33333347},	/* 0.671373=f(0.3)*/
{64, 0,123,__LINE__, 0x3fe527aa, 0x18422750, 0x3fd3d70a, 0x3d70a3eb},	/* 0.661092=f(0.31)*/
{63, 0,123,__LINE__, 0x3fe4d3f5, 0xb8c56c8d, 0x3fd47ae1, 0x47ae148f},	/* 0.650874=f(0.32)*/
{64, 0,123,__LINE__, 0x3fe480ca, 0x0cd77f06, 0x3fd51eb8, 0x51eb8533},	/* 0.640721=f(0.33)*/
{63, 0,123,__LINE__, 0x3fe42e2a, 0x7045312f, 0x3fd5c28f, 0x5c28f5d7},	/* 0.630635=f(0.34)*/
{63, 0,123,__LINE__, 0x3fe3dc1a, 0x2ae85671, 0x3fd66666, 0x6666667b},	/* 0.620618=f(0.35)*/
{63, 0,123,__LINE__, 0x3fe38a9c, 0x70494f48, 0x3fd70a3d, 0x70a3d71f},	/* 0.61067=f(0.36)*/
{64, 0,123,__LINE__, 0x3fe339b4, 0x5f455ebf, 0x3fd7ae14, 0x7ae147c3},	/* 0.600794=f(0.37)*/
{63, 0,123,__LINE__, 0x3fe2e965, 0x01b9d7a5, 0x3fd851eb, 0x851eb867},	/* 0.590991=f(0.38)*/
{63, 0,123,__LINE__, 0x3fe299b1, 0x4c342e6f, 0x3fd8f5c2, 0x8f5c290b},	/* 0.581261=f(0.39)*/
{63, 0,123,__LINE__, 0x3fe24a9c, 0x1da6faf3, 0x3fd99999, 0x999999af},	/* 0.571608=f(0.4)*/
{63, 0,123,__LINE__, 0x3fe1fc28, 0x3f23f3c4, 0x3fda3d70, 0xa3d70a53},	/* 0.562031=f(0.41)*/
{64, 0,123,__LINE__, 0x3fe1ae58, 0x639aeb30, 0x3fdae147, 0xae147af7},	/* 0.552532=f(0.42)*/
{63, 0,123,__LINE__, 0x3fe1612f, 0x279dd467, 0x3fdb851e, 0xb851eb9b},	/* 0.543113=f(0.43)*/
{64, 0,123,__LINE__, 0x3fe114af, 0x1129d5b6, 0x3fdc28f5, 0xc28f5c3f},	/* 0.533775=f(0.44)*/
{64, 0,123,__LINE__, 0x3fe0c8da, 0x8f756b16, 0x3fdccccc, 0xcccccce3},	/* 0.524518=f(0.45)*/
{63, 0,123,__LINE__, 0x3fe07db3, 0xfac39ae0, 0x3fdd70a3, 0xd70a3d87},	/* 0.515345=f(0.46)*/
{63, 0,123,__LINE__, 0x3fe0333d, 0x943c3cc2, 0x3fde147a, 0xe147ae2b},	/* 0.506255=f(0.47)*/
{63, 0,123,__LINE__, 0x3fdfd2f3, 0x0b92a331, 0x3fdeb851, 0xeb851ecf},	/* 0.49725=f(0.48)*/
{64, 0,123,__LINE__, 0x3fdf40d3, 0xc3f2d293, 0x3fdf5c28, 0xf5c28f73},	/* 0.488332=f(0.49)*/
{64, 0,123,__LINE__, 0x3fdeb021, 0x47ce2448, 0x3fe00000, 0x0000000b},	/* 0.4795=f(0.5)*/
{64, 0,123,__LINE__, 0x3fde20df, 0x5e4a97be, 0x3fe051eb, 0x851eb85d},	/* 0.470756=f(0.51)*/
{63, 0,123,__LINE__, 0x3fdd9311, 0x9f61ed99, 0x3fe0a3d7, 0x0a3d70af},	/* 0.462101=f(0.52)*/
{62, 0,123,__LINE__, 0x3fdd06bb, 0x73ce6cc2, 0x3fe0f5c2, 0x8f5c2901},	/* 0.453536=f(0.53)*/
{63, 0,123,__LINE__, 0x3fdc7be0, 0x15017997, 0x3fe147ae, 0x147ae153},	/* 0.445061=f(0.54)*/
{63, 0,123,__LINE__, 0x3fdbf282, 0x8d23e7d5, 0x3fe19999, 0x999999a5},	/* 0.436677=f(0.55)*/
{62, 0,123,__LINE__, 0x3fdb6aa5, 0xb71fed2a, 0x3fe1eb85, 0x1eb851f7},	/* 0.428384=f(0.56)*/
{64, 0,123,__LINE__, 0x3fdae44c, 0x3eb497ac, 0x3fe23d70, 0xa3d70a49},	/* 0.420184=f(0.57)*/
{63, 0,123,__LINE__, 0x3fda5f78, 0xa092a8d4, 0x3fe28f5c, 0x28f5c29b},	/* 0.412077=f(0.58)*/
{64, 0,123,__LINE__, 0x3fd9dc2d, 0x2a82b31f, 0x3fe2e147, 0xae147aed},	/* 0.404064=f(0.59)*/
{62, 0,123,__LINE__, 0x3fd95a6b, 0xfb9455ff, 0x3fe33333, 0x3333333f},	/* 0.396144=f(0.6)*/
{62, 0,123,__LINE__, 0x3fd8da37, 0x04567168, 0x3fe3851e, 0xb851eb91},	/* 0.388319=f(0.61)*/
{62, 0,123,__LINE__, 0x3fd85b90, 0x071827f1, 0x3fe3d70a, 0x3d70a3e3},	/* 0.380589=f(0.62)*/
{64, 0,123,__LINE__, 0x3fd7de78, 0x9832845a, 0x3fe428f5, 0xc28f5c35},	/* 0.372954=f(0.63)*/
{64, 0,123,__LINE__, 0x3fd762f2, 0x1e5a952a, 0x3fe47ae1, 0x47ae1487},	/* 0.365414=f(0.64)*/
{64, 0,123,__LINE__, 0x3fd6e8fd, 0xd2fbcef6, 0x3fe4cccc, 0xccccccd9},	/* 0.357971=f(0.65)*/
{64, 0,123,__LINE__, 0x3fd6709c, 0xc29a8410, 0x3fe51eb8, 0x51eb852b},	/* 0.350623=f(0.66)*/
{63, 0,123,__LINE__, 0x3fd5f9cf, 0xcd3e3e73, 0x3fe570a3, 0xd70a3d7d},	/* 0.343372=f(0.67)*/
{64, 0,123,__LINE__, 0x3fd58497, 0xa6e3c703, 0x3fe5c28f, 0x5c28f5cf},	/* 0.336218=f(0.68)*/
{63, 0,123,__LINE__, 0x3fd510f4, 0xd7f6a38c, 0x3fe6147a, 0xe147ae21},	/* 0.32916=f(0.69)*/
{63, 0,123,__LINE__, 0x3fd49ee7, 0xbdd1d362, 0x3fe66666, 0x66666673},	/* 0.322199=f(0.7)*/
{62, 0,123,__LINE__, 0x3fd42e70, 0x8b479108, 0x3fe6b851, 0xeb851ec5},	/* 0.315334=f(0.71)*/
{64, 0,123,__LINE__, 0x3fd3bf8f, 0x492fdde7, 0x3fe70a3d, 0x70a3d717},	/* 0.308567=f(0.72)*/
{63, 0,123,__LINE__, 0x3fd35243, 0xd6fd9be1, 0x3fe75c28, 0xf5c28f69},	/* 0.301896=f(0.73)*/
{64, 0,123,__LINE__, 0x3fd2e68d, 0xeb59f755, 0x3fe7ae14, 0x7ae147bb},	/* 0.295322=f(0.74)*/
{62, 0,123,__LINE__, 0x3fd27c6d, 0x14c5e330, 0x3fe80000, 0x0000000d},	/* 0.288844=f(0.75)*/
{64, 0,123,__LINE__, 0x3fd213e0, 0xba416795, 0x3fe851eb, 0x851eb85f},	/* 0.282463=f(0.76)*/
{62, 0,123,__LINE__, 0x3fd1ace8, 0x1bf882e2, 0x3fe8a3d7, 0x0a3d70b1},	/* 0.276178=f(0.77)*/
{63, 0,123,__LINE__, 0x3fd14782, 0x53f55c15, 0x3fe8f5c2, 0x8f5c2903},	/* 0.26999=f(0.78)*/
{64, 0,123,__LINE__, 0x3fd0e3ae, 0x56d784d2, 0x3fe947ae, 0x147ae155},	/* 0.263897=f(0.79)*/
{63, 0,123,__LINE__, 0x3fd0816a, 0xf49008eb, 0x3fe99999, 0x999999a7},	/* 0.257899=f(0.8)*/
{63, 0,123,__LINE__, 0x3fd020b6, 0xd92208aa, 0x3fe9eb85, 0x1eb851f9},	/* 0.251997=f(0.81)*/
{64, 0,123,__LINE__, 0x3fcf8321, 0x1acf35c9, 0x3fea3d70, 0xa3d70a4b},	/* 0.246189=f(0.82)*/
{63, 0,123,__LINE__, 0x3fcec7ec, 0xefb56714, 0x3fea8f5c, 0x28f5c29d},	/* 0.240476=f(0.83)*/
{62, 0,123,__LINE__, 0x3fce0fcd, 0xbac3967f, 0x3feae147, 0xae147aef},	/* 0.234857=f(0.84)*/
{62, 0,123,__LINE__, 0x3fcd5abf, 0xc440091f, 0x3feb3333, 0x33333341},	/* 0.229332=f(0.85)*/
{62, 0,123,__LINE__, 0x3fcca8bf, 0x14911662, 0x3feb851e, 0xb851eb93},	/* 0.2239=f(0.86)*/
{62, 0,123,__LINE__, 0x3fcbf9c7, 0x75e9d431, 0x3febd70a, 0x3d70a3e5},	/* 0.21856=f(0.87)*/
{64, 0,123,__LINE__, 0x3fcb4dd4, 0x75fc2a5a, 0x3fec28f5, 0xc28f5c37},	/* 0.213313=f(0.88)*/
{62, 0,123,__LINE__, 0x3fcaa4e1, 0x67afc7bc, 0x3fec7ae1, 0x47ae1489},	/* 0.208157=f(0.89)*/
{63, 0,123,__LINE__, 0x3fc9fee9, 0x64dd744d, 0x3feccccc, 0xccccccdb},	/* 0.203092=f(0.9)*/
{64, 0,123,__LINE__, 0x3fc95be7, 0x500e3c39, 0x3fed1eb8, 0x51eb852d},	/* 0.198117=f(0.91)*/
{62, 0,123,__LINE__, 0x3fc8bbd5, 0xd63df148, 0x3fed70a3, 0xd70a3d7f},	/* 0.193232=f(0.92)*/
{63, 0,123,__LINE__, 0x3fc81eaf, 0x70a08125, 0x3fedc28f, 0x5c28f5d1},	/* 0.188436=f(0.93)*/
{62, 0,123,__LINE__, 0x3fc6ed0c, 0xce964d24, 0x3fee6666, 0x66666675},	/* 0.179109=f(0.95)*/
{62, 0,123,__LINE__, 0x3fc65884, 0x91b7a8af, 0x3feeb851, 0xeb851ec7},	/* 0.174576=f(0.96)*/
{61, 0,123,__LINE__, 0x3fc5c6cf, 0x6bbeb412, 0x3fef0a3d, 0x70a3d719},	/* 0.17013=f(0.97)*/
{62, 0,123,__LINE__, 0x3fc537e6, 0xedc87022, 0x3fef5c28, 0xf5c28f6b},	/* 0.165768=f(0.98)*/
{62, 0,123,__LINE__, 0x3fc4abc4, 0x7fe9ee7c, 0x3fefae14, 0x7ae147bd},	/* 0.161492=f(0.99)*/
{63, 0,123,__LINE__, 0x3fc42261, 0x62fbddbe, 0x3ff00000, 0x00000007},	/* 0.157299=f(1)*/
{64, 0,123,__LINE__, 0x3fc39bb6, 0xb2651f4b, 0x3ff028f5, 0xc28f5c30},	/* 0.15319=f(1.01)*/
{63, 0,123,__LINE__, 0x3fc317bd, 0x65e3f739, 0x3ff051eb, 0x851eb859},	/* 0.149162=f(1.02)*/
{64, 0,123,__LINE__, 0x3fc2966e, 0x5355697a, 0x3ff07ae1, 0x47ae1482},	/* 0.145216=f(1.03)*/
{64, 0,123,__LINE__, 0x3fc217c2, 0x307a5a4c, 0x3ff0a3d7, 0x0a3d70ab},	/* 0.14135=f(1.04)*/
{64, 0,123,__LINE__, 0x3fc19bb1, 0x94ba0a82, 0x3ff0cccc, 0xccccccd4},	/* 0.137564=f(1.05)*/
{63, 0,123,__LINE__, 0x3fc12234, 0xfae18b5d, 0x3ff0f5c2, 0x8f5c28fd},	/* 0.133856=f(1.06)*/
{64, 0,123,__LINE__, 0x3fc0ab44, 0xc2dfc867, 0x3ff11eb8, 0x51eb8526},	/* 0.130227=f(1.07)*/
{63, 0,123,__LINE__, 0x3fc036d9, 0x337dc8f9, 0x3ff147ae, 0x147ae14f},	/* 0.126674=f(1.08)*/
{64, 0,123,__LINE__, 0x3fbf89d4, 0xf8259c51, 0x3ff170a3, 0xd70a3d78},	/* 0.123197=f(1.09)*/
{63, 0,123,__LINE__, 0x3fbeaae1, 0x6c67e9db, 0x3ff19999, 0x999999a1},	/* 0.119795=f(1.1)*/
{64, 0,123,__LINE__, 0x3fbdd0c7, 0xcebe0f58, 0x3ff1c28f, 0x5c28f5ca},	/* 0.116467=f(1.11)*/
{62, 0,123,__LINE__, 0x3fbcfb78, 0x05405b07, 0x3ff1eb85, 0x1eb851f3},	/* 0.113212=f(1.12)*/
{64, 0,123,__LINE__, 0x3fbc2ae1, 0xd4645220, 0x3ff2147a, 0xe147ae1c},	/* 0.110029=f(1.13)*/
{64, 0,123,__LINE__, 0x3fbb5ef4, 0xe231b77c, 0x3ff23d70, 0xa3d70a45},	/* 0.106918=f(1.14)*/
{64, 0,123,__LINE__, 0x3fba97a0, 0xb96b8c26, 0x3ff26666, 0x6666666e},	/* 0.103876=f(1.15)*/
{63, 0,123,__LINE__, 0x3fb9d4d4, 0xccac81ad, 0x3ff28f5c, 0x28f5c297},	/* 0.100904=f(1.16)*/
{64, 0,123,__LINE__, 0x3fb91680, 0x79765cb4, 0x3ff2b851, 0xeb851ec0},	/* 0.0979996=f(1.17)*/
{64, 0,123,__LINE__, 0x3fb85c93, 0x0b33cd4e, 0x3ff2e147, 0xae147ae9},	/* 0.0951626=f(1.18)*/
{63, 0,123,__LINE__, 0x3fb7a6fb, 0xbe2c4969, 0x3ff30a3d, 0x70a3d712},	/* 0.0923917=f(1.19)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc01921fb, 0x54442d18},	/* 2=f(-6.28319)*/
{46, 0,123,__LINE__, 0x3fffffff, 0xfffe2c40, 0xc012d97c, 0x7f3321d2},	/* 2=f(-4.71239)*/
{64, 0,123,__LINE__, 0x3ffffff6, 0xb153ddbe, 0xc00921fb, 0x54442d18},	/* 1.99999=f(-3.14159)*/
{64, 0,123,__LINE__, 0x3fff9430, 0x5a403fb6, 0xbff921fb, 0x54442d18},	/* 1.97368=f(-1.5708)*/
{64, 0,123,__LINE__, 0x3ff00000, 0x00000000, 0x00000000, 0x00000000},	/* 1=f(0)*/
{62, 0,123,__LINE__, 0x3f9af3e9, 0x6ff0126a, 0x3ff921fb, 0x54442d18},	/* 0.0263211=f(1.5708)*/
{62, 0,123,__LINE__, 0x3ee29d58, 0x448397ef, 0x400921fb, 0x54442d18},	/* 8.87615e-06=f(3.14159)*/
{11, 0,123,__LINE__, 0x3dbd3c03, 0x8386b7e6, 0x4012d97c, 0x7f3321d2},	/* 2.65886e-11=f(4.71239)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc03e0000, 0x00000000},	/* 2=f(-30)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc03c4ccc, 0xcccccccd},	/* 2=f(-28.3)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc03a9999, 0x9999999a},	/* 2=f(-26.6)*/
{11, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc038e666, 0x66666667},	/* 2=f(-24.9)*/
{ 1, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0373333, 0x33333334},	/* 2=f(-23.2)*/
{ 0, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0358000, 0x00000001},	/* 2=f(-21.5)*/
{12, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc033cccc, 0xccccccce},	/* 2=f(-19.8)*/
{10, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0321999, 0x9999999b},	/* 2=f(-18.1)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0306666, 0x66666668},	/* 2=f(-16.4)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc02d6666, 0x6666666a},	/* 2=f(-14.7)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc02a0000, 0x00000004},	/* 2=f(-13)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0269999, 0x9999999e},	/* 2=f(-11.3)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc0233333, 0x33333338},	/* 2=f(-9.6)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc01f9999, 0x999999a3},	/* 2=f(-7.9)*/
{64, 0,123,__LINE__, 0x40000000, 0x00000000, 0xc018cccc, 0xccccccd6},	/* 2=f(-6.2)*/
{43, 0,123,__LINE__, 0x3fffffff, 0xfff27d18, 0xc0120000, 0x00000009},	/* 2=f(-4.5)*/
{64, 0,123,__LINE__, 0x3fffffb1, 0x57cc83a9, 0xc0066666, 0x66666678},	/* 1.99992=f(-2.8)*/
{64, 0,123,__LINE__, 0x3ffe1551, 0xe939816c, 0xbff19999, 0x999999bd},	/* 1.88021=f(-1.1)*/
{62, 0,123,__LINE__, 0x3fd95a6b, 0xfb945682, 0x3fe33333, 0x333332ec},	/* 0.396144=f(0.6)*/
{61, 0,123,__LINE__, 0x3f52bad4, 0x8659492f, 0x40026666, 0x66666654},	/* 0.00114318=f(2.3)*/
{62, 0,123,__LINE__, 0x3e508ddd, 0x13bd371a, 0x400fffff, 0xffffffee},	/* 1.54173e-08=f(4)*/
{11, 0,123,__LINE__, 0x3ccb4299, 0x3551229a, 0x4016cccc, 0xccccccc4},	/* 7.56621e-16=f(5.7)*/
{11, 0,123,__LINE__, 0x3ac3515d, 0x737d743b, 0x401d9999, 0x99999991},	/* 1.24839e-25=f(7.4)*/
{11, 0,123,__LINE__, 0x3836c9d2, 0xb35d7c8a, 0x40223333, 0x3333332f},	/* 6.6969e-38=f(9.1)*/
{11, 0,123,__LINE__, 0x3525ff30, 0x0260c9b9, 0x40259999, 0x99999995},	/* 1.14829e-52=f(10.8)*/
{11, 0,123,__LINE__, 0x3191345b, 0x1de4a978, 0x4028ffff, 0xfffffffb},	/* 6.23194e-70=f(12.5)*/
{11, 0,123,__LINE__, 0x2d75ac5f, 0xcafcd239, 0x402c6666, 0x66666661},	/* 1.06396e-89=f(14.2)*/
{11, 0,123,__LINE__, 0x28d5e5e0, 0x93faea9c, 0x402fcccc, 0xccccccc7},	/* 5.69096e-112=f(15.9)*/
{ 3, 0,123,__LINE__, 0x23b1b1bd, 0xee206a73, 0x40319999, 0x99999997},	/* 9.50945e-137=f(17.6)*/
{64, 0,123,__LINE__, 0x1e06d249, 0x0dba141b, 0x40334ccc, 0xccccccca},	/* 4.95376e-164=f(19.3)*/
{64, 0,123,__LINE__, 0x17d77457, 0x7e1fbadd, 0x4034ffff, 0xfffffffd},	/* 8.03245e-194=f(21)*/
{64, 0,123,__LINE__, 0x11232f5c, 0xa5224730, 0x4036b333, 0x33333330},	/* 4.04926e-226=f(22.7)*/
{64, 0,123,__LINE__, 0x09e8f4bb, 0x92ece23f, 0x40386666, 0x66666663},	/* 6.34028e-261=f(24.4)*/
{64, 0,123,__LINE__, 0x0229cb1a, 0x25271190, 0x403a1999, 0x99999996},	/* 3.08122e-298=f(26.1)*/
{64, 0, 34,__LINE__, 0x00000000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 0=f(27.8)*/
{64, 0, 34,__LINE__, 0x00000000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 0=f(29.5)*/
{0}
};
void test_erfc(m)   {run_vector_1(m,erfc_vec,(char *)(erfc),"erfc","dd");   }	
